@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.130930';
+our $VERSION = '0.131002';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -80,6 +80,7 @@ use Acme::CPANAuthors::Register (
     HAOYAYOI  => 'Soshi Tamura',
     HATA      => 'Masanori HATA',
     HATAK     => 'Hisashi HATAKEYAMA',
+    HATENA    => 'Hatena',
     HATTORI   => 'Fumiaki Hattori',
     HAYAJO    => 'Hayato Imai',
     HAYASHI   => 'Hiroo HAYASHI',
@@ -158,6 +159,7 @@ use Acme::CPANAuthors::Register (
     KIRIRIMOD => 'Yuichi Kiri',
     KISEKI    => 'keita iseki',
     KITAMAKI  => 'ryo kitamaki',
+    KITANO    => 'dann',
     KIWANAMI  => 'Masashi Sakurai',
     KMIYAZAKI => 'Keitaro Miyazaki',
     KNAGANO   => 'Keiichiro Nagano',
@@ -181,6 +183,7 @@ use Acme::CPANAuthors::Register (
     KUMA      => 'KUMAGAI Kentaro',
     KUMAKATSU => 'katsuki ookuma',
     KUNIYOSHI => 'Kuniyoshi Kouji',
+    KURAMAKO  => 'makoto',
     KURIHARA  => 'Yoshiki KURIHARA',
     KURIYAMA  => 'Jun Kuriyama',
     KUZUHA    => 'Kuzuha SHINODA',
@@ -235,6 +238,7 @@ use Acme::CPANAuthors::Register (
     MIZZY     => 'Gosuke Miyashita',
     MONMON    => 'Nobuo Kumagai',
     MORIYA    => 'Moriya Masaki',
+    MOTEMEN   => 'motemen',
     MOZNION   => 'Taiki Kawakami',
     MRMT      => 'Jun Morimoto',
     MUGENKEN  => 'Mugen Kenichi',
@@ -243,6 +247,7 @@ use Acme::CPANAuthors::Register (
     MURATAYA  => 'MURATA Yasuhisa',
     MUYOSHI   => 'Mutsutoshi Yoshimoto',
     MYB       => 'Masayuki Iwai',
+    MYFINDER  => 'TatsuroHisamori',
     MYUJI     => 'Yuji Maeda',
     NABESHIMA => 'Masaaki NABESHIMA',
     NAGATA    => 'Ichito Nagata',
@@ -254,6 +259,7 @@ use Acme::CPANAuthors::Register (
     NAOYAT    => 'Naoya "naochan" Tozuka',
     NAOYUKI   => 'Naoyuki Ito',
     NARAZAKA  => 'N Narazaka',
+    NARIPON   => 'nari',
     NARITOSHI => 'Naritoshi Hayashi',
     NARUSE    => 'NARUSE, Yui',
     NEJIGANE  => 'Yu Nejigane',
@@ -265,6 +271,7 @@ use Acme::CPANAuthors::Register (
     NISHIKAWA => 'Kazuhiro Nishikawa',
     NODAJUN   => 'JUNICHI NODA',
     NOGUCHI   => 'Tatsuya Noguchi',
+    NORAYUNI  => 'Takahito Yamatoya',
     NORITAKA  => 'Noritaka Okabe',
     NOZZZZZ   => 'Tetsunari Nozaki',
     NTAKANASI => 'Nao Takanashi',
@@ -279,6 +286,7 @@ use Acme::CPANAuthors::Register (
     OINUME    => 'Kazuhiro Oinuma',
     OISHI     => 'Eisuke Oishi',
     ONISHI    => 'Yasuhiro Onishi',
+    OPPARA    => 'oppara',
     OUEST     => 'Daisuke NISHISAKA',
     OVERLAST  => 'Toshinori Sato',
     OYAMA     => 'Hiroyuki OYAMA',
@@ -292,6 +300,7 @@ use Acme::CPANAuthors::Register (
     PIROLIX   => 'Hiroyuki UENISHI',
     POCKET    => 'Masato Sogame',
     POPPEN    => 'Shinsuke Matsui',
+    PUNYTAN   => 'punipuni',
     QUEEN     => 'Yasuhiro Miyazaki',
     RIMFS     => 'Yuichiro Tanaka',
     RINTARO   => 'Rintaro Ishizaki',
@@ -379,6 +388,7 @@ use Acme::CPANAuthors::Register (
     TARAO     => 'INA Lintaro',
     TARO      => 'Daisuke Komatsu',
     TAROK     => 'Taro Kawagishi',
+    TATE      => 'tateisu',
     TATENO    => 'Yuichi Tateno',
     TAWAN     => 'Taro Funaki',
     THORIKAWA => 'Takahiro Horikawa',
@@ -408,6 +418,7 @@ use Acme::CPANAuthors::Register (
     TURUGINA  => 'KATOU Akira',
     TXIWASAKI => 'Tooru Iwasaki',
     TYANO     => 'Tatsuhiro YANO',
+    TYOSHII   => 'TakanaoYoshii',
     TYPESTER  => 'Daisuke Murase',
     TYRU      => 'Takuya Fujiwara',
     UASI      => 'Tomoki Aonuma',
@@ -415,6 +426,7 @@ use Acme::CPANAuthors::Register (
     UGUTOMO   => 'Tomohiro Horiuchi',
     UMEMOTO   => 'Hajimu Umemoto',
     UMEYUKI   => 'Hiromitsu Ito',
+    UMIYOSH   => 'umiyoshi',
     UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
     UTAANI    => 'Takeshi Ueno',
